/**
 * DynamicReports - Free Java reporting library for creating reports dynamically
 *
 * Copyright (C) 2010 - 2014 Ricardo Mariaca
 * http://www.dynamicreports.org
 *
 * This file is part of DynamicReports.
 *
 * DynamicReports is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * DynamicReports is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with DynamicReports. If not, see <http://www.gnu.org/licenses/>.
 */

package net.sf.dynamicreports.examples.exporter;

import static net.sf.dynamicreports.report.builder.DynamicReports.*;

import java.math.BigDecimal;

import net.sf.dynamicreports.examples.Templates;
import net.sf.dynamicreports.jasper.builder.export.JasperXlsExporterBuilder;
import net.sf.dynamicreports.jasper.constant.JasperProperty;
import net.sf.dynamicreports.report.builder.column.TextColumnBuilder;
import net.sf.dynamicreports.report.datasource.DRDataSource;
import net.sf.dynamicreports.report.exception.DRException;
import net.sf.jasperreports.engine.JRDataSource;

/**
 * @author Ricardo Mariaca (r.mariaca@dynamicreports.org)
 */
public class ExcelReport2 {

	public ExcelReport2() {
		build();
	}

	private void build() {
		try {
			JasperXlsExporterBuilder xlsExporter = export.xlsExporter("c:/report.xls")
			                                             .setDetectCellType(true)
			                                             .setIgnorePageMargins(true)
			                                             .setWhitePageBackground(false)
			                                             .setRemoveEmptySpaceBetweenColumns(true);

			TextColumnBuilder<String> itemColumn = col.column("Item", "item", type.stringType())
			                                          .setFixedWidth(30)
			                                          .setStretchWithOverflow(false)
			                                          .addProperty(JasperProperty.PRINT_KEEP_FULL_TEXT, "true");

			report()
			  .setColumnTitleStyle(Templates.columnTitleStyle)
			  .addProperty(JasperProperty.EXPORT_XLS_FREEZE_ROW, "2")
			  .ignorePageWidth()
			  .ignorePagination()
			  .columns(
			  	itemColumn,
			  	col.column("Quantity",   "quantity",  type.integerType()),
			  	col.column("Unit price", "unitprice", type.bigDecimalType()))
			  .setDataSource(createDataSource())
			  .toXls(xlsExporter);
		} catch (DRException e) {
			e.printStackTrace();
		}
	}

	private JRDataSource createDataSource() {
		DRDataSource dataSource = new DRDataSource("item", "quantity", "unitprice");
		for (int i = 0; i < 5; i++) {
			dataSource.add("Very long book name", (int) (Math.random() * 10) + 1, new BigDecimal(Math.random() * 100 + 1));
		}
		return dataSource;
	}

	public static void main(String[] args) {
		new ExcelReport2();
	}
}